@@ -1,6 +1,6 @@
 ;;; navi2ch-board.el --- subject list module for navi2ch
 
-;; Copyright (C) 2000-2003 by Navi2ch Project
+;; Copyright (C) 2000-2004 by Navi2ch Project
 
 ;; Author: Taiki SUGAWARA <taiki@users.sourceforge.net>
 ;; Keywords: network, 2ch
@@ -22,8 +22,8 @@
 
 ;;; Code:
 (provide 'navi2ch-board)
-(defvar navi2ch-board-ident
-  "$Id: navi2ch-board.el,v 1.66 2003/07/16 12:30:48 mami Exp $")
+(defconst navi2ch-board-ident
+  "$Id: navi2ch-board.el,v 1.70 2004/05/02 14:41:51 nanashi Exp $")
 
 (eval-when-compile (require 'cl))
 
@@ -217,12 +217,18 @@
       (dolist (x navi2ch-list-board-name-list)
 	(when (string= (cdr (assq 'uri x)) uri)
 	  (setq board x)))
-      (unless board
-	(setq board (list (cons 'uri uri)
-			  (cons 'id id)
-			  (cons 'type 'board)
-			  (cons 'name "No Name"))))
-      board)))
+      (or board
+	  (let* ((alist (navi2ch-alist-list-to-alist
+			 navi2ch-list-board-name-list
+			 'id 'name))
+		 (host (navi2ch-url-to-host uri))
+		 (name (concat (or (cdr (assoc id alist))
+				   "No Name")
+			       "(" host ")")))
+	    (list (cons 'uri uri)
+		  (cons 'id id)
+		  (cons 'type 'board)
+		  (cons 'name name)))))))
 
 (defun navi2ch-board-to-url (board)
   "BOARD $B$+$i(B url $B$KJQ49(B"
@@ -547,20 +553,11 @@
 	  (message msg))
       (message "Can't select this line!"))))
 
-
-;;; from Wanderlust(wl-expire.el)
-(defsubst navi2ch-board-expire-date-p (key-datevec file access-time)
-  (let ((datevec
-	 (condition-case nil
-	     (navi2ch-make-datevec
-	      (or access-time
-		  (nth 5 (file-attributes file))))
-	   (error nil))))
-    (and
-     datevec (> (aref datevec 1) 0)
-     (string<
-      (navi2ch-make-sortable-date datevec)
-      (navi2ch-make-sortable-date key-datevec)))))
+(defsubst navi2ch-board-expire-date-p (key-time file access-time)
+  (let ((time (ignore-errors (or access-time
+				 (nth 5 (file-attributes file))))))
+    (and time key-time
+	 (navi2ch-compare-times key-time time))))
 
 (defun navi2ch-board-expire (&optional board ask)
   (interactive)
@@ -578,9 +575,8 @@
 						  (match-string 0 file)))))
 				  (directory-files dir nil "\\.dat$")))
 	    (summary (navi2ch-article-load-article-summary board))
-	    (key-datevec (navi2ch-get-offset-datevec
-			  (navi2ch-make-datevec (current-time))
-			  navi2ch-board-expire-date))
+	    (key-time (navi2ch-add-days-to-time (current-time)
+						navi2ch-board-expire-date))
 	    (remove-list nil))
 	(message "expiring %s..." (cdr (assq 'name board)))
 	(dolist (article article-list)
@@ -590,8 +586,10 @@
 			   (not (or (member artid (cdr (assq 'bookmark board)))
 				    (navi2ch-bookmark-exist-all board
 								article))))
+		       (and navi2ch-board-expire-orphan-only
+			    (navi2ch-article-orphan-p board article))
 		       (navi2ch-board-expire-date-p
-			key-datevec file
+			key-time file
 			(navi2ch-article-summary-element-access-time
 			 (cdr (assoc artid summary)))))
 	      (push article remove-list)
